==> dali4x-sdk-buildrepo-R-3.4.0-20120612174739.zip: org/eclipse/jpt/jpa/core/context/orm/OrmTableGenerator.java <==
/*******************************************************************************
 * Copyright (c) 2008, 2010 Oracle. All rights reserved.
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v1.0, which accompanies this distribution
 * and is available at http://www.eclipse.org/legal/epl-v10.html.
 * 
 * Contributors:
 *     Oracle - initial API and implementation
 ******************************************************************************/
package org.eclipse.jpt.jpa.core.context.orm;

import org.eclipse.jpt.jpa.core.context.TableGenerator;
import org.eclipse.jpt.jpa.core.context.java.JavaTableGenerator;
import org.eclipse.jpt.jpa.core.resource.orm.XmlTableGenerator;

/**
 * <code>orm.xml</code> table generator
 * <p>
 * Provisional API: This interface is part of an interim API that is still
 * under development and expected to change significantly before reaching
 * stability. It is available at this early stage to solicit feedback from
 * pioneering adopters on the understanding that any code that uses this API
 * will almost certainly be broken (repeatedly) as the API evolves.
 * 
 * @version 2.1
 * @since 2.0
 */
public interface OrmTableGenerator
	extends TableGenerator, OrmGenerator
{
	XmlTableGenerator getXmlGenerator();


	// ********** unique constraints **********

	@SuppressWarnings("unchecked")
	Iterable<OrmUniqueConstraint> getUniqueConstraints();

	OrmUniqueConstraint addUniqueConstraint();

	OrmUniqueConstraint addUniqueConstraint(int index);


	//********* metadata conversion *********
	
	/**
	 * Build up a mapping file generator from the given Java generator.
	 */
	void convertFrom(JavaTableGenerator javaGenerator);
}

==> dali4x-sdk-buildrepo-R-3.5.0-20130610150119.zip: org/eclipse/jpt/jpa/core/context/orm/OrmTableGenerator.java <==
/*******************************************************************************
 * Copyright (c) 2008, 2012 Oracle. All rights reserved.
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v1.0, which accompanies this distribution
 * and is available at http://www.eclipse.org/legal/epl-v10.html.
 * 
 * Contributors:
 *     Oracle - initial API and implementation
 ******************************************************************************/
package org.eclipse.jpt.jpa.core.context.orm;

import org.eclipse.jpt.jpa.core.context.TableGenerator;
import org.eclipse.jpt.jpa.core.context.java.JavaTableGenerator;
import org.eclipse.jpt.jpa.core.resource.orm.XmlTableGenerator;

/**
 * <code>orm.xml</code> table generator
 * <p>
 * Provisional API: This interface is part of an interim API that is still
 * under development and expected to change significantly before reaching
 * stability. It is available at this early stage to solicit feedback from
 * pioneering adopters on the understanding that any code that uses this API
 * will almost certainly be broken (repeatedly) as the API evolves.
 * 
 * @version 3.3
 * @since 2.0
 */
public interface OrmTableGenerator
	extends TableGenerator, OrmGenerator
{
	XmlTableGenerator getXmlGenerator();


	// ********** unique constraints **********

	@SuppressWarnings("unchecked")
	Iterable<OrmSpecifiedUniqueConstraint> getUniqueConstraints();

	OrmSpecifiedUniqueConstraint addUniqueConstraint();

	OrmSpecifiedUniqueConstraint addUniqueConstraint(int index);


	//********* metadata conversion *********
	
	/**
	 * Build up a mapping file generator from the given Java generator.
	 */
	void convertFrom(JavaTableGenerator javaGenerator);
}
